memberships

# XMLRésuméLibrary: User Guide

membership | Element Reference | middlenames

## Name

memberships — Container for one or more memberships

## Synopsis

### Content Model

    (title,membership+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `memberships` element contains one or more `membership`s.

### Parents

`memberships` may be contained in these elements: `resume`

## Examples

    <memberships>
      <title>Professional Memberships</title>
      <membership>
        <organization>Foobar State Technology Association</organization>
      </membership>
      <membership>
        <title>President</title>
        <organization>Smallville Internet Developers' Group</organization>
        <period>
          <from><date>
            <month>September</month>
            <year>1998</year>
          </date></from>
          <to><present/></to>
        </period>
        <description>
          <para>
            Founded group and guided its growth from 4 to 150 members.
          </para>
        </description>
      </membership>
    </memberships>

membership | Element Reference | middlenames